<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\Models\Lead;
use App\Models\PinCode;
use Illuminate\Support\Facades\Auth;

class AdminController extends Controller
{
    public function getUsers()
    {
        $users = User::select('id', 'name', 'pincode')->get();

        return response()->json(['users' => $users]);
    }

    public function index(Request $request)
    {
        $pageNumber = $request->get('page', 1);
        $searchQuery = trim($request->get('search'));
        $count = 5;

        $dealers = User::with('pincode')->select('users.*')
            ->where('role', 'Dealer')
            ->when($searchQuery, function ($query) use ($searchQuery) {
                return $query->where(function ($query) use ($searchQuery) {
                    $fields = ['users.name', 'users.email', 'users.mobile', 'users.pincode'];
                    foreach ($fields as $index => $field) {
                        if ($index === 0) {
                            $query->whereRaw("LOCATE(?, $field) > 0", [$searchQuery]);
                        } else {
                            $query->orWhereRaw("LOCATE(?, $field) > 0", [$searchQuery]);
                        }
                    }
                });
            })
            ->orderBy('users.id', 'DESC');

        $totalCount = $dealers->count();

        $dealersPaginated = $dealers->paginate($count, ['*'], 'page', $pageNumber);

        return response()->json([
            'data' => $dealersPaginated->items(),
            'totalCount' => $totalCount,
            'current_page' => $dealersPaginated->currentPage(),
            'last_page' => $dealersPaginated->lastPage(),
            'next_page_url' => $dealersPaginated->nextPageUrl(),
            'prev_page_url' => $dealersPaginated->previousPageUrl(),
        ]);
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6',
            'mobile' => 'required|digits:10',
            'pincode'  => 'required|digits:6|unique:pin_codes,pincode',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        try {
            DB::beginTransaction();

            $user = User::create([
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'mobile' => $request->mobile,
                'role' => 'Dealer',
            ]);

            PinCode::create([
                'pincode' => $request->pincode,
                'user_id' => $user->id,
            ]);

            DB::commit();

            return response()->json(['message' => 'Dealer created successfully'], 201);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json(['message' => 'Something went wrong!'], 500);
        }
    }

    public function updateLeadAssignedUser(Request $request)
    {
        $request->validate([
            'lead_id' => 'required|exists:leads,id',
            'user_id' => 'required|exists:users,id'
        ]);

        $lead = Lead::find($request->lead_id);
        $lead->user_id = $request->user_id;
        $lead->save();

        return response()->json(['message' => 'Lead assigned successfully!'], 200);
    }

    public function addPincode(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'dealer_id' => 'required|exists:users,id',
            'pincode' => 'required|digits:6|numeric'
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        if (DB::table('pin_codes')->where('pincode', $request->pincode)->exists()) {
            return response()->json(['errors' => ['pincode' => ['Pincode Already Exists.']]], 422);
        }

        PinCode::create([
            'pincode' => $request->pincode,
            'user_id' => $request->dealer_id,
        ]);

        return response()->json(['message' => 'Pincode added successfully']);
    }

    public function dealerLeadList()
    {
            if (Auth::check()) {
                $user = Auth::user();
                if ($user) {
                    return view('dealerLead');
                } else {
                    return redirect()->route('login');
                }
            }
        
    }

    public function getdealerLead(Request $request)
    {
            $user = User::where('id',$request->id)->first();

            $dealerName = $user->name;
            $dealerPincode = PinCode::select('pincode')->where('user_id',$user->id)->get();

            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }
    
            $users = [];
            if (Auth::user()->role == 'Admin') {
                $users = User::with('pincode')
                    ->select('id', 'name', 'pincode')
                    ->where('role', '!=', 'Admin')
                    ->get();
            }
    
            $pageNumber = $request->get('page', 1);
            $searchQuery = trim($request->get('search'));
            $perPage = 5;
    
            $leadsQuery = Lead::where('user_id', $user->id);
    
            if (!empty($searchQuery)) {
                $leadsQuery->where(function ($query) use ($searchQuery) {
                    $fields = [
                        'full_name',
                        'status',
                        'phone_number',
                        'email',
                        'employment_status',
                        'vehicle_preference',
                        'date_of_birth'
                    ];
                    foreach ($fields as $index => $field) {
                        if ($index === 0) {
                            $query->where($field, 'like', "%{$searchQuery}%");
                        } else {
                            $query->orWhere($field, 'like', "%{$searchQuery}%");
                        }
                    }
                    $query->orWhereRaw("CONCAT_WS(', ', street, city, state, zip_code) LIKE ?", ["%{$searchQuery}%"]);
                });
            }
    
            $leads = $leadsQuery->orderBy('created_at', 'desc')->paginate($perPage, ['*'], 'page', $pageNumber);
    
            $totalLeads = Lead::where('user_id', $user->id)->count();
    
            $leadsPerStatus = Lead::select('status', DB::raw('COUNT(*) as total_leads'))->where('user_id',$user->id)
                ->groupBy('status')
                ->pluck('total_leads', 'status');
    
            $formattedLeads = $leads->map(function ($lead) {
                $lead->address = trim("{$lead->street}, {$lead->city}, {$lead->state} - {$lead->zip_code}", ', ');
                return $lead;
            });
    
            return response()->json([
                'data' => $formattedLeads,
                'dealerName' => $dealerName,
                'dealerPincode' => $dealerPincode,
                'users' => $users,
                'total_leads' => $totalLeads,
                'leads_per_status' => $leadsPerStatus,
                'pagination' => [
                    'current_page' => $leads->currentPage(),
                    'last_page' => $leads->lastPage(),
                    'next_page_url' => $leads->nextPageUrl(),
                    'prev_page_url' => $leads->previousPageUrl(),
                ],
            ]);
    }
}
