<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\Models\Lead;
use App\Models\PinCode;
use Illuminate\Support\Facades\Auth;
use Carbon\Carbon;
use App\Jobs\SendRegisterMailJob;
use App\Jobs\ImageRequestJob;
use App\Jobs\ReportIssueJob;
use App\Jobs\GeneralQueryJob;
use App\Mail\GeneralQueryMail;
use stdClass;

class DealerController extends Controller
{
    public function leadList()
    {
        if (Auth::check()) {

            $user = Auth::user();
            if ($user) {
                return view('dealer');
            } else {
                return redirect()->route('login');
            }
        }
    }

    public function getLeads(Request $request)
    {
        $user = auth()->user();

        if (!$user) {
            return response()->json(['error' => 'Unauthorized'], 401);
        }

        $users = [];
        if ($user->role == 'Admin') {
            $users = User::with('pincode')
                ->select('id', 'name', 'pincode')
                ->where('role', '!=', 'Admin')
                ->get();
        }

        $pageNumber = $request->get('page', 1);
        $searchQuery = trim($request->get('search'));
        $perPage = 5;

        $leadsQuery = Lead::where('user_id', $user->id);

        if (!empty($searchQuery)) {
            $leadsQuery->where(function ($query) use ($searchQuery) {
                $fields = [
                    'full_name',
                    'status',
                    'phone_number',
                    'email',
                    'employment_status',
                    'vehicle_preference',
                    'date_of_birth'
                ];
                foreach ($fields as $index => $field) {
                    if ($index === 0) {
                        $query->where($field, 'like', "%{$searchQuery}%");
                    } else {
                        $query->orWhere($field, 'like', "%{$searchQuery}%");
                    }
                }
                $query->orWhereRaw("CONCAT_WS(', ', street, city, state, zip_code) LIKE ?", ["%{$searchQuery}%"]);
            });
        }

        $leads = $leadsQuery->orderBy('created_at', 'desc')->paginate($perPage, ['*'], 'page', $pageNumber);

        $totalLeads = Lead::where('user_id', $user->id)->count();

        $leadsPerStatus = Lead::select('status', DB::raw('COUNT(*) as total_leads'))->where('user_id', $user->id)
            ->groupBy('status')
            ->pluck('total_leads', 'status');

        $formattedLeads = $leads->map(function ($lead) {
            $lead->address = trim("{$lead->street}, {$lead->city}, {$lead->state} - {$lead->zip_code}", ', ');
            return $lead;
        });

        return response()->json([
            'data' => $formattedLeads,
            'users' => $users,
            'total_leads' => $totalLeads,
            'leads_per_status' => $leadsPerStatus,
            'pagination' => [
                'current_page' => $leads->currentPage(),
                'last_page' => $leads->lastPage(),
                'next_page_url' => $leads->nextPageUrl(),
                'prev_page_url' => $leads->previousPageUrl(),
            ],
        ]);
    }

    public function updateStatus(Request $request, $id)
    {
        $lead = Lead::findOrFail($id);
        $lead->status = $request->status;
        $lead->status_change_date = Carbon::now();
        $lead->save();

        return response()->json(['message' => 'Status updated successfully']);
    }

    public function storeLead(Request $request)
    {
        $data = $request->input('args', []);

        \Log::info('Received Lead Data:', [$data]);

        \Log::info('Customer Info:', $data['customer_info'] ?? []);
        \Log::info('Address:', $data['address'] ?? []);
        \Log::info('Employment Details:', $data['employment_details'] ?? []);
        \Log::info('Residence Details:', $data['residence_details'] ?? []);
        \Log::info('Financial Info:', $data['financial_info'] ?? []);
        \Log::info('Vehicle Preferences:', $data['vehicle_preferences'] ?? []);

        $pinCode = $data['address']['zip_code'] ?? 0;

        $user_id = PinCode::where('pincode', $pinCode)->value('id') ?? 1;

        $lead = Lead::create([
            'user_id' =>  $user_id,
            'full_name' => $data['customer_info']['full_name'] ?? null,
            'phone_number' => $data['customer_info']['phone_number'] ?? null,
            'email' => $data['customer_info']['email'] ?? null,
            'date_of_birth' => $data['customer_info']['date_of_birth'] ?? null,

            'street' => $data['address']['street'] ?? null,
            'city' => $data['address']['city'] ?? null,
            'state' => $data['address']['state'] ?? null,
            'zip_code' => $data['address']['zip_code'] ?? null,

            'employment_status' => $data['employment_details']['employment_status'] ?? null,
            'employer_name' => $data['employment_details']['employer_name'] ?? null,
            'job_title' => $data['employment_details']['job_title'] ?? null,
            'employment_duration' => $data['employment_details']['employment_duration'] ?? null,
            'monthly_income' => $data['employment_details']['monthly_income'] ?? null,
            'work_phone' => $data['employment_details']['work_phone'] ?? null,

            'housing_status' => $data['residence_details']['housing_status'] ?? null,
            'monthly_payment' => $data['residence_details']['monthly_payment'] ?? null,
            'residence_duration' => $data['residence_details']['residence_duration'] ?? null,

            'bankruptcy_history' => $data['financial_info']['bankruptcy_history'] ?? null,
            'co_signer' => $data['financial_info']['co_signer'] ?? null,
            'social_security_number' => $data['financial_info']['social_security_number'] ?? null,
            'credit_check_consent' => $data['financial_info']['credit_check_consent'] ?? null,

            'vehicle_type' => $data['vehicle_preferences']['vehicle_type'] ?? null,
            'vehicle_preference' => $data['vehicle_preferences']['vehicle_preference'] ?? null
        ]);

        return response()->json(['message' => 'Lead stored successfully!'], 200);
    }

    public function bookRequest(Request $request)
    {
        $data = $request->input('args', []);
        \Log::info('Received Lead Data:', [$data]);

        $type = $request->input('name', null);
        \Log::info('Type Data:', [$type]);

        if ($type === 'register_photographer') {

            $name = $data['args']['name'] ?? null;
            $portfolio_link = $data['args']['portfolio_link'] ?? null;
            $location = $data['args']['location'] ?? null;
            $email = $data['args']['email'] ?? null;
            $admin_email = 'picturedesk@nurphoto.com';

            \Log::info('DATA:', [$name, $portfolio_link, $location, $email, $admin_email]);

            SendRegisterMailJob::dispatch($name, $portfolio_link, $location, $email, $admin_email);
        } elseif ($type === 'image_purchase_request') {

            \Log::info('image_purchase_request:', [$type]);


            $description = $data['args']['description'] ?? null;
            $usage = $data['args']['usage'] ?? null;
            $client_name = $data['args']['client_name'] ?? null;
            $phone = $data['args']['phone'] ?? null;
            $email = $data['args']['email'] ?? null;

            $admin_email = 'sales@nurphoto.com';

            \Log::info('image_purchase_request @NEYR:', [$description, $usage, $client_name, $email, $admin_email, $phone]);

            ImageRequestJob::dispatch($description, $usage, $client_name, $email, $admin_email, $phone);

            return response()->json(['message' => 'Your Image Purchase Request stored successfully!'], 200);
        } elseif ($type === 'report_issue') {

            \Log::info('report_issue:', [$type]);


            $issue_description = $data['args']['issue_description'] ?? null;
            $caller_name = $data['args']['caller_name'] ?? null;
            $phone = $data['args']['phone'] ?? null;
            $email = $data['args']['email'] ?? null;

            $admin_email = 'picturedesk@nurphoto.com';

            \Log::info('report_issue @NEYR:', [$issue_description, $caller_name, $email, $admin_email, $phone]);


            ReportIssueJob::dispatch($issue_description, $caller_name, $email, $admin_email, $phone);

            return response()->json(['message' => 'Your Report Issue Request stored successfully!'], 200);
        } elseif ($type === 'log_general_query') {

            \Log::info('log_general_query:', [$type]);


            $query_details = $data['args']['query_details'] ?? null;
            $caller_name = $data['args']['caller_name'] ?? null;
            $phone = $data['args']['phone'] ?? null;
            $email = $data['args']['email'] ?? null;

            $admin_email = 'picturedesk@nurphoto.com';

            \Log::info('log_general_query @NEYR:', [$query_details, $caller_name, $email, $admin_email, $phone]);

            GeneralQueryJob::dispatch($query_details, $caller_name, $email, $admin_email, $phone);

            return response()->json(['message' => 'Your General Query Request stored successfully!'], 200);
        }

        return response()->json(['message' => 'Request stored successfully!'], 200);
    }

    public function testmail(Request $request)
    {

        $data = new stdClass();


        $query_details = "ABC";
        $caller_name = "ABC";
        $email = "nachiket@samcomtechnologies.com";
        $admin_email = "admin@samcomtechnologies.com";
        $phone = "+919574702471";

        try {
            \Mail::to('nachiket@samcomtechnologies.com')->send(new GeneralQueryMail($query_details, $caller_name, $email, $admin_email, $phone));
        } catch (\Throwable $th) {
            dd($th);
        }
    }

    public function test()
    {
        return response()->json(['message' => ' API is properly set Up successfully!'], 200);
    }
}
